@@ -1,6 +1,7 @@
 from prettytable import PrettyTable
 from colored import fg, bg, attr
 from .core import main
+import sys
 
 import argparse
 
@@ -15,11 +16,11 @@ reset = attr('reset')
 
 
 def runner():
+    exit_code = 0
     parser = argparse.ArgumentParser()
     parser.add_argument('--nodes', nargs='+', )
     arguments = parser.parse_args()
     resp, total_requests, overall_time_spent = main(nodes=arguments.nodes or default_nodes)
-
     for api_type, call in resp.items():
         table = PrettyTable()
         table.field_names = ["#", "Node", "Call", "Status", "Time [ms]",
@@ -27,6 +28,8 @@ def runner():
         table.align = "l"
         for sub_call, scan_statuses in call.items():
             for scan_status, scan_results in scan_statuses.items():
+                if not scan_status:
+                    exit_code = 1
                 i = 1
                 for scan_result in scan_results:
                     table.add_row(
@@ -40,3 +43,4 @@ def runner():
                     i += 1
         print(table.get_string(title=f"{api_type}"))
     print(f" > {total_requests} requests sent in {overall_time_spent} seconds.")
+    sys.exit(exit_code)
